==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchive.md <==
# AmazonSimpleStorageServiceS3GlacierDeepArchive


```text
aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchive
```

```text
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchive')
```



| Illustration | AmazonSimpleStorageServiceS3GlacierDeepArchive | AmazonSimpleStorageServiceS3GlacierDeepArchiveCard | AmazonSimpleStorageServiceS3GlacierDeepArchiveGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchive.png) | ![illustration for AmazonSimpleStorageServiceS3GlacierDeepArchive](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchive.Local.png) | ![illustration for AmazonSimpleStorageServiceS3GlacierDeepArchiveCard](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchiveCard.Local.png) | ![illustration for AmazonSimpleStorageServiceS3GlacierDeepArchiveGroup](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchiveGroup.Local.png) |




## AmazonSimpleStorageServiceS3GlacierDeepArchive

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3GlacierDeepArchive
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchive')

' renders the element
AmazonSimpleStorageServiceS3GlacierDeepArchive('AmazonSimpleStorageServiceS3GlacierDeepArchive', 'Amazon Simple Storage Service S3 Glacier Deep Archive', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3GlacierDeepArchive
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchive')

' renders the element
AmazonSimpleStorageServiceS3GlacierDeepArchive('AmazonSimpleStorageServiceS3GlacierDeepArchive', 'Amazon Simple Storage Service S3 Glacier Deep Archive', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceS3GlacierDeepArchiveCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3GlacierDeepArchiveCard
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchive')

' renders the element
AmazonSimpleStorageServiceS3GlacierDeepArchiveCard('AmazonSimpleStorageServiceS3GlacierDeepArchiveCard', 'Amazon Simple Storage Service S3 Glacier Deep Archive Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3GlacierDeepArchiveCard
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchive')

' renders the element
AmazonSimpleStorageServiceS3GlacierDeepArchiveCard('AmazonSimpleStorageServiceS3GlacierDeepArchiveCard', 'Amazon Simple Storage Service S3 Glacier Deep Archive Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceS3GlacierDeepArchiveGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3GlacierDeepArchiveGroup
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchive')

' renders the element
AmazonSimpleStorageServiceS3GlacierDeepArchiveGroup('AmazonSimpleStorageServiceS3GlacierDeepArchiveGroup', 'Amazon Simple Storage Service S3 Glacier Deep Archive Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3GlacierDeepArchiveGroup
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchive')

' renders the element
AmazonSimpleStorageServiceS3GlacierDeepArchiveGroup('AmazonSimpleStorageServiceS3GlacierDeepArchiveGroup', 'Amazon Simple Storage Service S3 Glacier Deep Archive Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchive.md <==
# AmazonSimpleStorageServiceS3GlacierDeepArchive


```text
aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchive
```

```text
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchive')
```



| Illustration | AmazonSimpleStorageServiceS3GlacierDeepArchive | AmazonSimpleStorageServiceS3GlacierDeepArchiveCard | AmazonSimpleStorageServiceS3GlacierDeepArchiveGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchive.png) | ![illustration for AmazonSimpleStorageServiceS3GlacierDeepArchive](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchive.Local.png) | ![illustration for AmazonSimpleStorageServiceS3GlacierDeepArchiveCard](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchiveCard.Local.png) | ![illustration for AmazonSimpleStorageServiceS3GlacierDeepArchiveGroup](../../../aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchiveGroup.Local.png) |




## AmazonSimpleStorageServiceS3GlacierDeepArchive

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3GlacierDeepArchive
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchive')

' renders the element
AmazonSimpleStorageServiceS3GlacierDeepArchive('AmazonSimpleStorageServiceS3GlacierDeepArchive', 'Amazon Simple Storage Service S3 Glacier Deep Archive', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3GlacierDeepArchive
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchive')

' renders the element
AmazonSimpleStorageServiceS3GlacierDeepArchive('AmazonSimpleStorageServiceS3GlacierDeepArchive', 'Amazon Simple Storage Service S3 Glacier Deep Archive', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceS3GlacierDeepArchiveCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3GlacierDeepArchiveCard
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchive')

' renders the element
AmazonSimpleStorageServiceS3GlacierDeepArchiveCard('AmazonSimpleStorageServiceS3GlacierDeepArchiveCard', 'Amazon Simple Storage Service S3 Glacier Deep Archive Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3GlacierDeepArchiveCard
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchive')

' renders the element
AmazonSimpleStorageServiceS3GlacierDeepArchiveCard('AmazonSimpleStorageServiceS3GlacierDeepArchiveCard', 'Amazon Simple Storage Service S3 Glacier Deep Archive Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceS3GlacierDeepArchiveGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3GlacierDeepArchiveGroup
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchive')

' renders the element
AmazonSimpleStorageServiceS3GlacierDeepArchiveGroup('AmazonSimpleStorageServiceS3GlacierDeepArchiveGroup', 'Amazon Simple Storage Service S3 Glacier Deep Archive Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3GlacierDeepArchiveGroup
include('aws-20210730/Resource/Storage/AmazonSimpleStorageServiceS3GlacierDeepArchive')

' renders the element
AmazonSimpleStorageServiceS3GlacierDeepArchiveGroup('AmazonSimpleStorageServiceS3GlacierDeepArchiveGroup', 'Amazon Simple Storage Service S3 Glacier Deep Archive Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
